@@ -29,7 +29,7 @@
 
 #include <config.h>
 
-#ident "$Id: chage.c,v 1.71 2006/02/21 22:44:35 kloczek Exp $"
+#ident "$Id: chage.c,v 1.73 2006/07/11 13:15:41 kloczek Exp $"
 
 #include <ctype.h>
 #include <fcntl.h>
@@ -103,7 +103,7 @@ int isnum (const char *s)
  */
 static void usage (void)
 {
-	fprintf (stderr, _("Usage: chage [options] user\n"
+	fprintf (stderr, _("Usage: chage [options] [LOGIN]\n"
 			   "\n"
 			   "Options:\n"
 			   "  -d, --lastday LAST_DAY	set last password change to LAST_DAY\n"
@@ -116,7 +116,8 @@ static void usage (void)
 			   "				change to MIN_DAYS\n"
 			   "  -M, --maxdays MAX_DAYS	set maximim number of days before password\n"
 			   "				change to MAX_DAYS\n"
-			   "  -W, --warndays WARN_DAYS	set expiration warning days to WARN_DAYS\n"));
+			   "  -W, --warndays WARN_DAYS	set expiration warning days to WARN_DAYS\n"
+			   "\n"));
 	exit (E_USAGE);
 }
 
