@@ -29,7 +29,7 @@
 
 #include <config.h>
 
-#ident "$Id: newgrp.c,v 1.41 2005/09/07 15:00:45 kloczek Exp $"
+#ident "$Id: newgrp.c,v 1.44 2006/01/18 19:55:15 kloczek Exp $"
 
 #include <errno.h>
 #include <grp.h>
@@ -38,9 +38,11 @@
 #include "defines.h"
 #include "getdef.h"
 #include "prototypes.h"
+#include "exitcodes.h"
 /*
  * Global variables
  */
+extern char **newenvp;
 extern char **environ;
 
 #ifdef HAVE_SETGROUPS
@@ -103,6 +105,7 @@ int main (int argc, char **argv)
 	int needspasswd = 0;
 	int i;
 	int cflag = 0;
+	int err = 0;
 	gid_t gid;
 	char *cp;
 	const char *cpasswd, *name, *prog;
@@ -118,6 +121,9 @@ int main (int argc, char **argv)
 	struct sgrp *sgrp;
 #endif
 
+#ifdef WITH_AUDIT
+	audit_help_open ();
+#endif
 	setlocale (LC_ALL, "");
 	bindtextdomain (PACKAGE, LOCALEDIR);
 	textdomain (PACKAGE);
@@ -157,6 +163,10 @@ int main (int argc, char **argv)
 	pwd = get_my_pwent ();
 	if (!pwd) {
 		fprintf (stderr, _("unknown UID: %u\n"), getuid ());
+#ifdef WITH_AUDIT
+		audit_logger (AUDIT_USER_START, Prog, "changing", NULL,
+			      getuid (), 0);
+#endif
 		SYSLOG ((LOG_WARN, "unknown UID %u", getuid ()));
 		closelog ();
 		exit (1);
@@ -261,6 +271,10 @@ int main (int argc, char **argv)
 	}
 	if (ngroups < 0) {
 		perror ("getgroups");
+#ifdef WITH_AUDIT
+		audit_logger (AUDIT_USER_START, Prog,
+			      "changing", NULL, getuid (), 0);
+#endif
 		exit (1);
 	}
 #endif				/* HAVE_SETGROUPS */
@@ -383,7 +397,7 @@ int main (int argc, char **argv)
 			 * there is no password, print out "Sorry" and give up
 			 */
 			sleep (1);
-			fputs (_("Sorry.\n"), stderr);
+			fputs (_("No password.\n"), stderr);
 			goto failure;
 		}
 
@@ -392,7 +406,6 @@ int main (int argc, char **argv)
 				 "Invalid password for group `%s' from `%s'",
 				 group, name));
 			sleep (1);
-			fputs (_("Sorry.\n"), stderr);
 			goto failure;
 		}
 	}
@@ -453,6 +466,10 @@ int main (int argc, char **argv)
 			/* error in fork() */
 			fprintf (stderr, _("%s: failure forking: %s"),
 				 is_newgrp ? "newgrp" : "sg", strerror (errno));
+#ifdef WITH_AUDIT
+			audit_logger (AUDIT_USER_START, Prog, "changing",
+				      NULL, getuid (), 0);
+#endif
 			exit (1);
 		} else if (child) {
 			/* parent - wait for child to finish, then log session close */
@@ -467,8 +484,8 @@ int main (int argc, char **argv)
 					/* wake child when resumed */
 					kill (child, SIGCONT);
 				}
-			} while (pid == child && WIFSTOPPED (cst) ||
-				 pid != child && errno == EINTR);
+			} while ((pid == child && WIFSTOPPED (cst)) ||
+				 (pid != child && errno == EINTR));
 			SYSLOG ((LOG_INFO,
 				 "user `%s' (login `%s' on %s) returned to group `%s'",
 				 name, loginname, tty,
@@ -523,6 +540,10 @@ int main (int argc, char **argv)
 
 	if (setuid (getuid ())) {
 		perror ("setuid");
+#ifdef WITH_AUDIT
+		audit_logger (AUDIT_USER_START, Prog, "changing",
+			      NULL, getuid (), 0);
+#endif
 		exit (1);
 	}
 
@@ -533,13 +554,12 @@ int main (int argc, char **argv)
 	if (cflag) {
 		closelog ();
 		execl ("/bin/sh", "sh", "-c", command, (char *) 0);
-		if (errno == ENOENT) {
-			perror ("/bin/sh");
-			exit (127);
-		} else {
-			perror ("/bin/sh");
-			exit (126);
-		}
+#ifdef WITH_AUDIT
+		audit_logger (AUDIT_USER_START, Prog, "changing",
+			      NULL, getuid (), 0);
+#endif
+		perror ("/bin/sh");
+		exit (errno == ENOENT ? E_CMD_NOTFOUND : E_CMD_NOEXEC);
 	}
 
 	/*
@@ -601,11 +621,15 @@ int main (int argc, char **argv)
 			addenv (*envp++, NULL);
 	}
 
+#ifdef WITH_AUDIT
+	audit_logger (AUDIT_USER_START, Prog, "changing", NULL, getuid (), 1);
+#endif
 	/*
 	 * Exec the login shell and go away. We are trying to get back to
 	 * the previous environment which should be the user's login shell.
 	 */
-	shell (prog, initflag ? (char *) 0 : cp);
+	err = shell (prog, initflag ? (char *) 0 : cp, newenvp);
+	exit (err == ENOENT ? E_CMD_NOTFOUND : E_CMD_NOEXEC);
 	/* NOTREACHED */
       failure:
 
@@ -620,5 +644,8 @@ int main (int argc, char **argv)
 	 * harm.  -- JWP
 	 */
 	closelog ();
+#ifdef WITH_AUDIT
+	audit_logger (AUDIT_USER_START, Prog, "changing", NULL, getuid (), 0);
+#endif
 	exit (1);
 }
