@@ -26,10 +26,28 @@
  * OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF
  * SUCH DAMAGE.
  */
+/* Some parts substantially derived from an ancestor of: */
+/* su for GNU.  Run a shell with substitute user and group IDs.
+   Copyright (C) 1992-2003 Free Software Foundation, Inc.
+
+   This program is free software; you can redistribute it and/or modify
+   it under the terms of the GNU General Public License as published by
+   the Free Software Foundation; either version 2, or (at your option)
+   any later version.
+
+   This program is distributed in the hope that it will be useful,
+   but WITHOUT ANY WARRANTY; without even the implied warranty of
+   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+   GNU General Public License for more details.
+
+   You should have received a copy of the GNU General Public License
+   along with this program; if not, write to the Free Software Foundation,
+   Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.  */
+
 
 #include <config.h>
 
-#ident "$Id: su.c,v 1.70 2006/05/07 17:26:59 kloczek Exp $"
+#ident "$Id: su.c,v 1.74 2006/08/01 10:30:02 kloczek Exp $"
 
 #include <getopt.h>
 #include <grp.h>
@@ -140,7 +158,6 @@ static void su_failure (const char *tty)
 			 oldname[0] ? oldname : "???", name[0] ? name : "???"));
 	closelog ();
 #endif
-	puts (_("Sorry."));
 	exit (1);
 }
 
@@ -252,7 +269,7 @@ static void run_shell (const char *shellstr, char *args[], int doshell,
   */
 static void usage (void)
 {
-	fprintf (stderr, _("Usage: su [options] [login]\n"
+	fprintf (stderr, _("Usage: su [options] [LOGIN]\n"
 			   "\n"
 			   "Options:\n"
 			   "  -c, --command COMMAND		pass COMMAND to the invoked shell\n"
@@ -261,7 +278,8 @@ static void usage (void)
 			   "  -m, -p,\n"
 			   "  --preserve-environment	do not reset environment variables, and keep\n"
 			   "				the same shell\n"
-			   "  -s, --shell SHELL		use SHELL instead of the default in passwd\n"));
+			   "  -s, --shell SHELL		use SHELL instead of the default in passwd\n"
+			   "\n"));
 	exit (E_USAGE);
 }
 
@@ -278,7 +296,6 @@ static void usage (void)
 int main (int argc, char **argv)
 {
 	char *cp;
-	char **envcp;
 	const char *tty = 0;	/* Name of tty SU is run from        */
 	int doshell = 0;
 	int fakelogin = 0;
@@ -289,6 +306,7 @@ int main (int argc, char **argv)
 	char *shellstr = 0, *command = 0;
 
 #ifdef USE_PAM
+	char **envcp;
 	int ret;
 #else				/* !USE_PAM */
 	int err = 0;
@@ -709,11 +727,6 @@ int main (int argc, char **argv)
 		addenv ("PATH", cp);
 	}
 
-#ifndef USE_PAM
-	/* setup the environment for PAM later on, else we run into auth problems */
-	environ = newenvp;	/* make new environment active */
-#endif
-
 	if (getenv ("IFS"))	/* don't export user IFS ... */
 		addenv ("IFS= \t\n", NULL);	/* ... instead, set a safe IFS */
 
@@ -793,7 +806,10 @@ int main (int argc, char **argv)
 		exit (1);
 	}
 #else				/* !USE_PAM */
-	if (!amroot)		/* no limits if su from root */
+	environ = newenvp;	/* make new environment active */
+
+	/* no limits if su from root (unless su must fake login's behavior) */
+	if (!amroot || fakelogin)
 		setup_limits (&pwent);
 
 	if (setup_uid_gid (&pwent, is_console))
